@@ -44,6 +44,7 @@ class ExportGethTracesJob(BaseJob):
         self.start_block = start_block
         self.end_block = end_block
 
+        self.batch_size = batch_size
         self.batch_web3_provider = batch_web3_provider
 
         self.batch_work_executor = BatchWorkExecutor(batch_size, max_workers)
@@ -71,7 +72,14 @@ class ExportGethTracesJob(BaseJob):
 
     def _export_batch(self, block_number_batch):
         trace_block_rpc = list(generate_trace_block_by_number_json_rpc(block_number_batch))
-        response = self.batch_web3_provider.make_batch_request(json.dumps(trace_block_rpc))
+
+        # For nodes that don't support batch debug_traceBlockByNumber
+        if self.batch_size == 1:
+            request = json.dumps(trace_block_rpc[0])
+            response = [self.batch_web3_provider.make_batch_request(request)]
+        else:
+            request = json.dumps(trace_block_rpc)
+            response = self.batch_web3_provider.make_batch_request(request)
 
         for response_item in response:
             block_number = response_item.get('id')
